## 0.2.0 (2021-03-28)

### Feat

- add rss support

### feat

- create newsletter landing page

## 0.1.0 (2021-03-19)

### Fix

- add dateutil to required dependencies
- Remove links from the Other section

### Feat

- create newsletters from changes
- create initial project structure
